@@ -4,7 +4,7 @@ import (
 	"testing"
 )
 
-func TestStatusLeader(t *testing.T) {
+func TestAPI_StatusLeader(t *testing.T) {
 	t.Parallel()
 	c, s := makeClient(t)
 	defer s.Stop()
@@ -20,7 +20,7 @@ func TestStatusLeader(t *testing.T) {
 	}
 }
 
-func TestStatusPeers(t *testing.T) {
+func TestAPI_StatusPeers(t *testing.T) {
 	t.Parallel()
 	c, s := makeClient(t)
 	defer s.Stop()
