@@ -1,14 +1,26 @@
 #!/usr/bin/env bash
 set -e
 
-export GO15VENDOREXPERIMENT=1
-
-# Get the version from the command line.
-VERSION=$1
+# Get the version from the environment, or try to figure it out from the build tags.
+# We process the files in the same order Go does to find the last matching tag.
 if [ -z $VERSION ]; then
-    echo "Please specify a version."
-    exit 1
+  # get the OSS version from version.go
+  VERSION=$(awk -F\" '/Version =/ { print $2; exit }' <version/version.go)
+
+  # if we have build tags then try to determine the version
+  for tag in "$GOTAGS"; do
+    for file in $(ls version/version_*.go | sort); do
+      if grep -q "// +build $tag" $file; then
+        VERSION=$(awk -F\" '/Version =/ { print $2; exit }' <$file)
+      fi
+    done
+  done
 fi
+if [ -z $VERSION ]; then
+  echo "Please specify a version (couldn't find one based on build tags)."
+  exit 1
+fi
+echo "==> Building version $VERSION..."
 
 # Get the parent directory of where this script is.
 SOURCE="${BASH_SOURCE[0]}"
@@ -27,8 +39,8 @@ fi
 
 # Do a hermetic build inside a Docker container.
 if [ -z $NOBUILD ]; then
-    docker build -t hashicorp/consul-builder scripts/consul-builder/
-    docker run --rm -v "$(pwd)":/gopath/src/github.com/hashicorp/consul hashicorp/consul-builder
+  docker build -t hashicorp/consul-builder scripts/consul-builder/
+  docker run --rm -e "GOTAGS=$GOTAGS" -v "$(pwd)":/gopath/src/github.com/hashicorp/consul hashicorp/consul-builder ./scripts/dist_build.sh
 fi
 
 # Zip all the files.
