@@ -1,8 +1,6 @@
 #!/usr/bin/env bash
 set -e
 
-export GO15VENDOREXPERIMENT=1
-
 # Get the parent directory of where this script is.
 SOURCE="${BASH_SOURCE[0]}"
 while [ -h "$SOURCE" ] ; do SOURCE="$(readlink "$SOURCE")"; done
@@ -11,8 +9,8 @@ DIR="$( cd -P "$( dirname "$SOURCE" )/.." && pwd )"
 # Change into that dir because we expect that.
 cd $DIR
 
-# Make sure build tools are abailable.
-make -f GNUMakefile tools
+# Make sure build tools are available.
+make tools
 
 # Build the standalone version of the web assets for the sanity check.
 pushd ui
@@ -24,24 +22,20 @@ popd
 # verify that the checked-in content is up to date without spurious diffs of the
 # file mod times.
 pushd pkg
-cat ../command/agent/bindata_assetfs.go | ../scripts/fixup_times.sh
+cat ../agent/bindata_assetfs.go | ../scripts/fixup_times.sh
 popd
 
 # Regenerate the built-in web assets. If there are any diffs after doing this
 # then we know something is up.
-make -f GNUMakefile static-assets
-if ! git diff --quiet command/agent/bindata_assetfs.go; then
+make static-assets
+if ! git diff --quiet agent/bindata_assetfs.go; then
    echo "Checked-in web assets are out of date, build aborted"
    exit 1
 fi
 
-# Now we are ready to do a clean build of everything. The "all" build will blow
-# away our pkg folder so we have to regenerate the ui once more. This is probably
-# for the best since we have meddled with the timestamps.
+# Now we are ready to do a clean build of everything. We no longer distribute the
+# web UI so it's ok that gets blown away as part of this.
 rm -rf pkg
-make -f GNUMakefile all
-pushd ui
-make dist
-popd
+make all
 
 exit 0
